********
Examples
********

Below are some links to projects that make extensive use of |PFF|.  Note that 
not all of these projects are completely up-to-date (both in terms of the 
package itself and the best-practices that I would currently advise), but it's 
still informative to see how things work "in the wild":

- `Stepwise <https://github.com/kalekundert/stepwise>`_
- `Stepwise — Molecular Biology <https://github.com/kalekundert/stepwise_mol_bio>`_
- `FreezerBox <https://github.com/kalekundert/freezerbox>`_

